# Copied Card

2019-05-07

Sample description

## Checklist

- [x] Completed item
- [ ] Incomplete item

## Empty Checklist

## Attachments

- <https://example.com/>
- [sample.jpg](https://trello-attachments.s3.amazonaws.com/5cd06090e0b6a35dd3522df9/5de109aa7674381358bad37e/a66c6f34c8ba393df8557e3e1ddba91a/sample.jpg)

## Comments

### bhrutledge on 2019-05-06

Sample comment

### bhrutledge on 2019-11-30

Another comment
